@@ -12,6 +12,7 @@ pub mod functions;
 /// Reference implementations of patterns.
 pub mod patterns {
     pub mod api_entry;
+    pub mod api_guard;
     pub mod ascii_pointer;
     pub mod callbacks;
     pub mod option;
@@ -64,6 +65,8 @@ interoptopus::inventory!(
         functions::namespaced_type,
         functions::panics,
         functions::sleep,
+        functions::weird_1,
+        functions::visibility,
         patterns::ascii_pointer::pattern_ascii_pointer_1,
         patterns::ascii_pointer::pattern_ascii_pointer_len,
         patterns::slice::pattern_ffi_slice_1,
@@ -74,9 +77,11 @@ interoptopus::inventory!(
         patterns::option::pattern_ffi_option_1,
         patterns::option::pattern_ffi_option_2,
         patterns::primitives::pattern_ffi_bool,
-        patterns::api_entry::my_api_init_v1,
+        patterns::api_entry::pattern_my_api_init_v1,
+        patterns::api_guard::pattern_api_guard,
         patterns::callbacks::pattern_callback_1
     ],
+    [types::ExtraType<f32>],
     [
         patterns::service_manual::my_service_pattern_context,
         patterns::service_generated::simple_service_pattern
