@@ -5,6 +5,7 @@ use interoptopus::lang::rust::CTypeInfo;
 use interoptopus::patterns::ascii_pointer::AsciiPointer;
 use interoptopus::patterns::slice::FFISlice;
 use interoptopus::{ffi_type, pattern_callback};
+use std::fmt::Debug;
 use std::marker::PhantomData;
 
 // Let's assume we can't implement `CTypeInfo` for this.
@@ -57,7 +58,7 @@ pub struct Generic3<T> {
     pub x: T,
 }
 
-#[ffi_type(skip(p))]
+#[ffi_type(unsafe, skip(p))]
 #[repr(C)]
 pub struct Phantom<'a, T>
 where
@@ -77,7 +78,7 @@ pub struct Vec3f32 {
     pub z: f32,
 }
 
-#[ffi_type(surrogates(foreign1 = "some_foreign_type", foreign2 = "some_foreign_type"))]
+#[ffi_type(unsafe, surrogates(foreign1 = "some_foreign_type", foreign2 = "some_foreign_type"))]
 #[repr(C)]
 pub struct Container {
     pub foreign1: SomeForeignType,
@@ -114,6 +115,8 @@ pub enum EnumDocumented {
     A,
     /// Variant B.
     B,
+    /// Variant B.
+    C,
 }
 
 /// Documented struct.
@@ -124,6 +127,12 @@ pub struct StructDocumented {
     pub x: f32,
 }
 
+#[ffi_type]
+#[repr(C)]
+pub struct ExtraType<T> {
+    pub x: T,
+}
+
 #[ffi_type]
 #[repr(C)]
 pub struct UseAsciiStringPattern<'a> {
@@ -137,6 +146,43 @@ pub struct Context {
     pub(crate) some_field: u32,
 }
 
+#[ffi_type]
+#[repr(C)]
+pub struct Weird1<T: Clone>
+where
+    T: Copy + Copy,
+{
+    x: T,
+}
+
+#[ffi_type]
+#[repr(C)]
+pub struct Weird2<'a, T: Clone, const N: usize>
+where
+    T: Copy + Copy + 'a,
+    T: Debug,
+{
+    t: T,
+    a: [T; N],
+    r: &'a u8,
+}
+
+#[ffi_type(visibility(pblc = "public", prvt = "private"))]
+#[repr(C)]
+pub struct Visibility1 {
+    // Be conservative with naming since some languages don't like `public` as a field.
+    pblc: u8,
+    pub prvt: u8,
+}
+
+#[ffi_type(visibility(_ = "public"))]
+#[repr(C)]
+
+pub struct Visibility2 {
+    pblc1: u8,
+    pblc2: u8,
+}
+
 // Doesn't need annotations.
 pub type Callbacku8u8 = extern "C" fn(u8) -> u8;
 
